Further Reading — SQLAlchemy 2.0 Documentation

Release: 2.0.17 | Release Date: June 23, 2023

# SQLAlchemy 2.0 Documentation

SQLAlchemy 1.4 / 2.0 Tutorial

This page is part of the SQLAlchemy Unified Tutorial.

Previous: Working with ORM Related Objects

# Further Reading

The sections below are the major top-level sections that discuss the concepts in this tutorial in much more detail, as well as describe many more features of each subsystem.

Core Essential Reference

- Working with Engines and Connections

- Schema Definition Language

- SQL Statements and Expressions API

- SQL Datatype Objects

ORM Essential Reference

- ORM Mapped Class Configuration

- Relationship Configuration

- Using the Session

- ORM Querying Guide